@@ -1,17 +1,19 @@
+from __future__ import annotations
+
 import re
 import shlex
 from collections.abc import Callable
 from pathlib import Path
 from textwrap import indent
-from typing import Any, Iterator, ParamSpec
+from typing import Any, Iterator, Union
 
 
-from.utils import serialize_callback, PLUGIN_PATH
+from.utils import serialize_callback, PLUGIN_PATH, P
 
 
-Params = str | int | bool | Path
+Params = Union[str, int, bool, Path]
 ParamsDict = dict[str, Params]
-P = ParamSpec('P')
+
 
 
 valid_params_re = re.compile('|'.join([
@@ -93,6 +95,12 @@ class ConfigurableItem(Item):
         self._alternate = cls(title, **params)
         return self._alternate
 
+    def clear(self) -> None:
+        self.title = ''
+        self._alternate = None
+        self._callbacks.clear()
+        self.params.clear()
+
 
 class NestableItem(ConfigurableItem):
 
@@ -111,3 +119,7 @@ class NestableItem(ConfigurableItem):
     def __repr__(self) -> str:
         children = ", ".join(repr(i) for i in self.children)
         return f'{self.__class__.__name__}("{self.title}", [{children}])'
+
+    def clear(self) -> None:
+        super().clear()
+        self.children.clear()
