@@ -1,19 +1,29 @@
+from __future__ import annotations
+
 import base64
 import os
 import pickle
 import subprocess
+import sys
 from collections.abc import Callable
 from pathlib import Path
-from typing import ParamSpec
 from urllib.parse import urlencode
 
 
-PLUGIN_PATH = Path(os.environ.get('SWIFTBAR_PLUGIN_PATH', '.'))
+if sys.version_info >= (3, 10):
+    from typing import ParamSpec
+else:
+    class ParamSpec:
+        def __init__(self, *args, **kwargs):
+            pass
 
 
 P = ParamSpec('P')
 
 
+PLUGIN_PATH = Path(os.environ.get('SWIFTBAR_PLUGIN_PATH', '.'))
+
+
 def serialize_callback(callback: Callable[P, object], *args: P.args, **kwargs: P.kwargs) -> str:
     cb_byt = pickle.dumps((callback, args, kwargs))
     cb_b64 = base64.b64encode(cb_byt)
